@@ -1,4 +1,3 @@
-import socket
 import logging
 import getpass
 import string
@@ -10,11 +9,11 @@ def fake2db_logger():
     '''creates a logger obj'''
     # Pull the local ip and username for meaningful logging
     username = getpass.getuser()
-    local_ip = socket.gethostbyname(socket.gethostname())
+    
     # Set the logger
-    FORMAT = '%(asctime)-15s %(clientip)s %(user)-8s %(message)s'
+    FORMAT = '%(asctime)-15s %(user)-8s %(message)s'
     logging.basicConfig(format=FORMAT)
-    extra_information = {'clientip': local_ip, 'user': username}
+    extra_information = {'user': username}
     logger = logging.getLogger('fake2db_logger')
     # --------------------
     return logger, extra_information
@@ -25,6 +24,11 @@ def str_generator(self):
     '''
     return ''.join(random.choice(string.ascii_uppercase) for i in range(8))
 
+def lower_str_generator(self):
+    '''generates lowercase 8 chars
+    '''
+    return ''.join(random.choice(string.ascii_lowercase) for i in range(8))
+
 
 def rnd_id_generator(self):
     '''generates a UUID such as :
