@@ -1,37 +1,59 @@
 import pymongo
-from helpers import fake2db_logger, str_generator, rnd_id_generator
+import sys
+from .base_handler import BaseHandler
+from .custom import faker_options_container
+from .helpers import fake2db_logger, str_generator, rnd_id_generator
 
 
 logger, extra_information = fake2db_logger()
 d = extra_information
 
-try:
-    from faker import Factory
-except ImportError:
-    logger.error('faker package not found onto python packages, please run : \
-    pip install -r requirements.txt  \
-    on the root of the project')
 
+class Fake2dbMongodbHandler(BaseHandler):
 
-class Fake2dbMongodbHandler():
-    faker = Factory.create()
-
-    def fake2db_mongodb_initiator(self, host, port, number_of_rows, name=None):
+    def fake2db_mongodb_initiator(self, host, port, number_of_rows, name=None, custom=None):
         '''Main handler for the operation
         '''
         rows = number_of_rows
+        db = self.database_caller_creator(host, port, name)
 
-        if name:
-            db = self.database_caller_creator(host, port, name)
-        else:
-            db = self.database_caller_creator(host, port)
-
+        if custom:
+            self.custom_db_creator(rows, db, custom)
+            sys.exit(0)
+            
         self.data_filler_simple_registration(rows, db)
         self.data_filler_detailed_registration(rows, db)
         self.data_filler_company(rows, db)
         self.data_filler_user_agent(rows, db)
         self.data_filler_customer(rows, db)
 
+
+    def custom_db_creator(self, number_of_rows, db, custom):
+        try:
+            customdb = db.custom
+            data_list = list()
+            custom_d = faker_options_container()
+            for c in custom:
+                if custom_d.get(c):
+                    logger.warning("fake2db found valid custom key provided: %s" % c, extra=d)
+                else:
+                    logger.error("fake2db does not support the custom key you provided.", extra=d )
+                    sys.exit(1)
+                    
+            for i in range(0, number_of_rows):
+                dict_c = {"id": rnd_id_generator(self)}
+                for c in custom:
+                    dict_c[c] = getattr(self.faker, c)()
+                          
+                data_list.append(dict_c)
+
+            customdb.insert_many(data_list)
+            logger.warning('custom Commits are successful after write job!', extra=d)
+
+        except Exception as e:
+            logger.error(e, extra=d)
+        
+    
     def database_caller_creator(self, host, port, name=None):
         '''creates a mongodb database
         returns the related connection object
@@ -61,7 +83,7 @@ class Fake2dbMongodbHandler():
                                    }
                 data_list.append(post_simple_reg)
 
-            simple_registration.insert(data_list)
+            simple_registration.insert_many(data_list)
             logger.warning('simple_registration Commits are successful after write job!', extra=d)
 
         except Exception as e:
@@ -79,11 +101,11 @@ class Fake2dbMongodbHandler():
                                 "email": self.faker.safe_email(),
                                 "password": self.faker.md5(raw_output=False),
                                 "lastname": self.faker.last_name(),
-                                "name": self.faker.name(),
+                                "name": self.faker.first_name(),
                                 "adress": self.faker.address(),
                                 "phone": self.faker.phone_number()}
                 data_list.append(post_det_reg)
-            detailed_registration.insert(data_list)
+            detailed_registration.insert_many(data_list)
 
             logger.warning('detailed_registration Commits are successful after write job!', extra=d)
 
@@ -103,7 +125,7 @@ class Fake2dbMongodbHandler():
                                "countrycode": self.faker.country_code(),
                                "useragent": self.faker.user_agent()}
                 data_list.append(post_uo_reg)
-            user_agent.insert(data_list)
+            user_agent.insert_many(data_list)
 
             logger.warning('user_agent Commits are successful after write job!', extra=d)
         except Exception as e:
@@ -124,7 +146,7 @@ class Fake2dbMongodbHandler():
                                  "domain": self.faker.safe_email(),
                                  "city": self.faker.city()}
                 data_list.append(post_comp_reg)
-            company.insert(data_list)
+            company.insert_many(data_list)
             logger.warning('companies Commits are successful after write job!', extra=d)
         except Exception as e:
             logger.error(e, extra=d)
@@ -138,7 +160,7 @@ class Fake2dbMongodbHandler():
             data_list = list()
             for i in range(0, number_of_rows):
                 post_cus_reg = {"id": rnd_id_generator(self),
-                                "name": self.faker.name(),
+                                "name": self.faker.first_name(),
                                 "lastname": self.faker.last_name(),
                                 "address": self.faker.address(),
                                 "country": self.faker.country(),
@@ -149,7 +171,7 @@ class Fake2dbMongodbHandler():
                                 "phone_number": self.faker.phone_number(),
                                 "locale": self.faker.locale()}
                 data_list.append(post_cus_reg)
-            customer.insert(data_list)
+            customer.insert_many(data_list)
 
             logger.warning('customer Commits are successful after write job!', extra=d)
         except Exception as e:
