@@ -1,35 +1,30 @@
 import sqlite3
-
-from helpers import fake2db_logger, str_generator, rnd_id_generator
+import sys
+from .base_handler import BaseHandler
+from .custom import faker_options_container
+from .helpers import fake2db_logger, str_generator, rnd_id_generator
 
 logger, extra_information = fake2db_logger()
 d = extra_information
 
-try:
-    from faker import Factory
-except ImportError:
-    logger.error('faker package not found onto python packages, please run : \
-    pip install -r requirements.txt  \
-    on the root of the project', extra=d)
-
 
 class DbConnException(Exception):
     """Database Connection or Creation Exception"""
 
 
-class Fake2dbSqliteHandler():
-    faker = Factory.create()
+class Fake2dbSqliteHandler(BaseHandler):
 
-    def fake2db_sqlite_initiator(self, number_of_rows, name=None):
+    def fake2db_sqlite_initiator(self, number_of_rows, name=None, custom=None):
         '''Main handler for the operation
         '''
         rows = number_of_rows
+        conn = self.database_caller_creator(name)
 
-        if name:
-            conn = self.database_caller_creator(name)
-        else:
-            conn = self.database_caller_creator()
-
+        if custom:
+            self.custom_db_creator(rows, conn, custom)
+            conn.close()
+            sys.exit(0)
+            
         self.data_filler_simple_registration(rows, conn)
         self.data_filler_detailed_registration(rows, conn)
         self.data_filler_company(rows, conn)
@@ -37,12 +32,50 @@ class Fake2dbSqliteHandler():
         self.data_filler_customer(rows, conn)
         conn.close()
 
+    def custom_db_creator(self, number_of_rows, conn, custom):
+        '''creates and fills the table with simple regis. information
+        '''
+        cursor = conn.cursor()
+        custom_d = faker_options_container()
+        sqlst = '''
+        CREATE TABLE custom(id TEXT PRIMARY KEY,'''
+
+        # first one is always ID primary key
+        exec_many = 'insert into custom values(?,'
+        
+        for c in custom:
+            if custom_d.get(c):
+                sqlst += " " + c + " TEXT, "
+                exec_many += '?,'
+                logger.warning("fake2db found valid custom key provided: %s" % c, extra=d)
+            else:
+                logger.error("fake2db does not support the custom key you provided.", extra=d )
+                sys.exit(1)
+                
+        sqlst = sqlst[:-2] + ")"
+        cursor.execute(sqlst)   
+        conn.commit()
+        multi_lines = []
+        exec_many = exec_many[:-1] +')'
+        
+        try:
+            for i in range(0, number_of_rows):
+                multi_lines.append([rnd_id_generator(self)])
+                for c in custom:
+                    multi_lines[i].append(getattr(self.faker, c)())
+            
+            cursor.executemany(exec_many, multi_lines)
+            conn.commit()
+            logger.warning('custom Commits are successful after write job!', extra=d)
+        except Exception as e:
+            logger.error(e, extra=d)
+
     def database_caller_creator(self, name=None):
         '''creates a sqlite3 db
         returns the related connection object
         which will be later used to spawn the cursor
         '''
-        database = ''
+
         try:
             if name:
                 database = name + '.db'
@@ -56,7 +89,7 @@ class Fake2dbSqliteHandler():
             raise DbConnException
 
         return conn
-
+    
     def data_filler_simple_registration(self, number_of_rows, conn):
         '''creates and fills the table with simple regis. information
         '''
@@ -86,7 +119,7 @@ class Fake2dbSqliteHandler():
         cursor.execute('''
         CREATE TABLE detailed_registration(id TEXT PRIMARY KEY,
         email TEXT, password TEXT, lastname TEXT,
-        name TEXT, adress TEXT, phone TEXT)
+        name TEXT, address TEXT, phone TEXT)
         ''')
         conn.commit()
         multi_lines = []
@@ -95,7 +128,7 @@ class Fake2dbSqliteHandler():
             for i in range(0, number_of_rows):
                 multi_lines.append((rnd_id_generator(self), self.faker.safe_email(),
                                     self.faker.md5(raw_output=False), self.faker.last_name(),
-                                    self.faker.name(), self.faker.address(), self.faker.phone_number()))
+                                    self.faker.first_name(), self.faker.address(), self.faker.phone_number()))
                 
             cursor.executemany('insert into detailed_registration values(?,?,?,?,?,?,?)', multi_lines)
             conn.commit()
@@ -168,7 +201,7 @@ class Fake2dbSqliteHandler():
         try:
             for i in range(0, number_of_rows):
                 
-                multi_lines.append((rnd_id_generator(self), self.faker.name(), self.faker.last_name(), self.faker.address(),
+                multi_lines.append((rnd_id_generator(self), self.faker.first_name(), self.faker.last_name(), self.faker.address(),
                                     self.faker.country(), self.faker.city(), self.faker.date(pattern="%d-%m-%Y"),
                                     self.faker.date(pattern="%d-%m-%Y"), self.faker.safe_email(), self.faker.phone_number(),
                                     self.faker.locale()))
